@@ -22,7 +22,7 @@
 #define LIBDICT_H 1
 
 #include "common.h"
-#include "aspell.h"
+#include "spell.h"
 #include "dictd.h"
 #include "prefs.h"
 #include "gui.h"
